@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::InlineFilesMARCEL;
 BEGIN {
-  $Dist::Zilla::Plugin::InlineFilesMARCEL::VERSION = '1.100950';
+  $Dist::Zilla::Plugin::InlineFilesMARCEL::VERSION = '1.100980';
 }
 # ABSTRACT: Write static files that I always use
 use Moose;
@@ -26,7 +26,7 @@ Dist::Zilla::Plugin::InlineFilesMARCEL - Write static files that I always use
 
 =head1 VERSION
 
-version 1.100950
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -66,11 +66,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-MARCEL/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Dist-Zilla-PluginBundle-MARCEL/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
